@@ -96,17 +96,17 @@ class FeedForwardWithCompressionState(nn.Module):
             self.net4 = nn.Dropout(dropout)
         else:
             self.net4 = nn.Identity()
-        # .state: torch.Size([]), x: torch.Size([128, 256, 256]), self.state_gate: torch.Size([1024, 1024]), self.state_zero: torch.Size([1024, 1024])
-        self.state_gate = torch.randn(hidden_size, hidden_size, device=device) / 10.0
-        self.state_zero = torch.zeros((hidden_size, hidden_size), device=device)
+        self.gatenet = nn.Linear(hidden_size, hidden_size, device=device)
+        # self.gateact = nn.Tanh()
+        self.state_zero = torch.zeros((1, input_size, hidden_size), device=device)
 
     def forward(self, x, state):
-        print(
-            f"state: {state.shape}, x: {x.shape}, self.state_gate: {self.state_gate.shape}, self.state_zero: {self.state_zero.shape}"
-        )
-        x = (self.net1(x).T + self.state_gate @ (self.state_zero + state)).T
-        x = self.net2(x)
+        x = self.net1(x)
+        state = self.gatenet(self.state_zero[:, -x.shape[1] :, :] + state))
+        # state = self.gateact(state)
+        x = x + state
         state = x
+        x = self.net2(x)
         x = self.net3(x)
         x = self.net4(x)
         return x, state
